@@ -403,6 +403,76 @@ IpMessengerAgent::AddBroadcastAddress( std::string addr )
 	IPMSG_FUNC_EXIT;
 }
 
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤ򥯥ꥢ
+ */
+void
+IpMessengerAgent::ClearSkulkHost()
+{
+	IPMSG_FUNC_ENTER("void IpMessengerAgent::ClearSkulkHost()");
+	ipmsgImpl->ClearSkulkHost();
+	IPMSG_FUNC_EXIT;
+}
+
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤ饢ɥ쥹
+ * @param host ϿѤθʤʱ˥ۥȥɥ쥹
+ */
+void
+IpMessengerAgent::DeleteSkulkHostAddress( std::string addr )
+{
+	IPMSG_FUNC_ENTER("void IpMessengerAgent::DeleteSkulkHostAddress( std::string addr )");
+	ipmsgImpl->DeleteSkulkHostAddress( addr );
+	IPMSG_FUNC_EXIT;
+}
+
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤۥȤ
+ * @param host ϿѤθʤʱ˥ۥ
+ */
+void
+IpMessengerAgent::DeleteSkulkHost( HostListItem &host )
+{
+	IPMSG_FUNC_ENTER("void IpMessengerAgent::DeleteSkulkHost( HostListItem &host )");
+	ipmsgImpl->DeleteSkulkHost( host );
+	IPMSG_FUNC_EXIT;
+}
+
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤ˥ۥȥɥ쥹ɲ
+ * @param host Ͽ븫ʤʱ˥ۥȥɥ쥹
+ */
+void
+IpMessengerAgent::AddSkulkHostAddress( std::string addr )
+{
+	IPMSG_FUNC_ENTER("void IpMessengerAgent::AddSkulkHostAddress( std::string )");
+	ipmsgImpl->AddSkulkHostAddress( addr );
+	IPMSG_FUNC_EXIT;
+}
+
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤ˥ۥȤɲ
+ * @param host Ͽ븫ʤʱ˥ۥ
+ */
+void
+IpMessengerAgent::AddSkulkHost( HostListItem &host )
+{
+	IPMSG_FUNC_ENTER("void IpMessengerAgent::AddSkulkHost( HostListItem &host )");
+	ipmsgImpl->AddSkulkHost( host );
+	IPMSG_FUNC_EXIT;
+}
+
+/**
+ * ΥۥȤ鱣硢ʤۥȤΥꥹȤ֤
+ * @retval Ͽ븫ʤʱ˥ۥȥꥹ
+ */
+HostList
+IpMessengerAgent::GetSkulkHost()
+{
+	IPMSG_FUNC_ENTER("HostList IpMessengerAgent::GetSkulkHost()");
+	IPMSG_FUNC_RETURN( ipmsgImpl->GetSkulkHost() );
+}
+
 /**
  * оݥۥȤΥС
  * @param host оݤΥۥ
