@@ -463,6 +463,14 @@ class AbsenceMode {
  **/
 class IpMessengerEvent {
 	public:
+		/**
+		 * Υ٥ȳ٥(GUIåɤΥåƤ)
+		 */
+		virtual void EventBefore()=0;
+		/**
+		 * Υ٥Ƚλ奤٥(GUIåɤΥåƤ)
+		 */
+		virtual void EventAfter()=0;
 		/**
 		 * ۥȥꥹȥեå奤٥
 		 * @param hostList ۥȥꥹ
@@ -641,6 +649,36 @@ class IpMessengerAgent {
 		 **/
 		void AddBroadcastAddress( std::string addr );
 
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥɥ쥹ΥꥹȤ˥ɥ쥹ɲ
+		 **/
+		void AddSkulkHostAddress( std::string addr );
+
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥꥹȤ˥ۥȤɲ
+		 **/
+		void AddSkulkHost( HostListItem &host );
+
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥɥ쥹ΥꥹȤ饢ɥ쥹
+		 **/
+		void DeleteSkulkHostAddress( std::string addr );
+
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥꥹȤۥȤ
+		 **/
+		void DeleteSkulkHost( HostListItem &host );
+
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥɥ쥹ΥꥹȤ򥯥ꥢ
+		 **/
+		void ClearSkulkHost();
+
+		/**
+		 * ΥۥȤ鱣硢ʤۥȥɥ쥹ΥꥹȤ֤
+		 **/
+		HostList GetSkulkHost();
+
 		/**
 		 * ΡʻΡ
 		 **/
