@@ -84,6 +84,13 @@ class IpMessengerAgentImpl {
 		void ClearBroadcastAddress();
 		void DeleteBroadcastAddress( std::string addr );
 		void AddBroadcastAddress( std::string addr );
+		void ClearSkulkHost();
+		void DeleteSkulkHostAddress( const std::string addr );
+		void AddSkulkHostAddress( const std::string addr );
+		void DeleteSkulkHost( const HostListItem &host );
+		void AddSkulkHost( const HostListItem &host );
+		HostList GetSkulkHost();
+
 		void Login( std::string nickname, std::string groupName );
 		void Logout();
 		HostList& GetHostList();
@@ -149,6 +156,7 @@ class IpMessengerAgentImpl {
 		struct timeval tv;
 		fd_set rfds;
 		std::vector<struct sockaddr_storage> broadcastAddr;
+		HostList skulkHostList;
 		std::vector<Packet> PacketsForChecking;
 		HostList appearanceHostList;
 		HostList hostList;
@@ -172,6 +180,7 @@ class IpMessengerAgentImpl {
 		bool RecvUdp( fd_set *fds, struct sockaddr_storage *sender_addr, int *sz, char *buf, int *udp_socket );
 		bool RecvTcp( fd_set *fds, struct sockaddr_storage *sender_addr, int *sz, char *buf, int *tcp_socket );
 		bool FindDuplicatePacket( const Packet &packet );
+		bool SkulkFromHost( const Packet &packet );
 		void PurgePacket( time_t nowTime );
 		void CheckSendMsgRetry( time_t nowTime );
 		void CheckGetHostListRetry( time_t nowTime );
@@ -181,6 +190,9 @@ class IpMessengerAgentImpl {
 		void DoRecvCommand( const Packet& packet );
 		int SendNoOperation();
 		int SendAbsence();
+		void VisibleToAddr( struct sockaddr_storage &addr );
+		void HideFromAllAddr();
+		void HideFromAddr( struct sockaddr_storage &addr );
 		int UdpRecvEventNoOperation( const Packet& packet );
 		int UdpRecvEventBrEntry( const Packet& packet );
 		int UdpRecvEventBrExit( const Packet& packet );
@@ -212,6 +224,7 @@ class IpMessengerAgentImpl {
 		bool EncryptMsg( const HostListItem &host, unsigned char *optBuf, int optBufLen, int *encOptBufLen, int optSize );
 		bool DecryptMsg( const Packet &packet, std::string& msg );
 		std::vector<struct sockaddr_storage>::iterator FindBroadcastNetworkByAddress( std::string addr );
+		std::vector<HostListItem>::iterator FindSkulkHostByAddress( std::string addr );
 		unsigned long AddCommonCommandOption( const unsigned long cmd );
 		bool IsFileChanged( time_t mtime, unsigned long long size, struct stat statInit, struct stat statProgress );
 
@@ -282,6 +295,7 @@ std::string getAddressFamilyString( int family );
 std::string getLocalhostAddress( bool useIpv6, const std::vector<NetworkInterface>& nics );
 bool isSameNetwork( const struct sockaddr_storage *addr, std::string ifnetaddr, std::string netmask );
 bool isSameSockAddrIn( struct sockaddr_storage base, struct sockaddr_storage check );
+bool isSameSockAddressFamily( struct sockaddr_storage base, struct sockaddr_storage check );
 void getNetworkInterfaceInfo( std::vector<NetworkInterface>& nics, bool useIPv6, int defaultPortNo );
 #ifndef HAVE_GETIFADDR
 void getNetworkInterfaceInfoForIPv4( std::vector<NetworkInterface>& nics, int defaultPortNo );
@@ -298,12 +312,14 @@ void IpMsgPrintBuf( const char* bufname, const char *buf, const int size );
 void IpMsgDumpPacket( ipmsg::Packet packet, struct sockaddr_storage *sender_addr );
 std::string GetCommandString( unsigned  long cmd );
 void IpMsgDumpHostList( const char *s, ipmsg::HostList& hostList );
+void IpMsgDumpHost( const char *s, const ipmsg::HostListItem& host );
 void IpMsgDumpAddr( const struct sockaddr_storage *addr );
 #else
 #define IpMsgPrintBuf( bufname, buf,size )
 #define IpMsgDumpPacket( packet, sender_addr )
 #define GetCommandString( cmd )
 #define IpMsgDumpHostList( s, hostList )
+#define IpMsgDumpHost( s, host )
 #define IpMsgDumpAddr( addr )
 #endif
 int IpMsgMutexInit( const char *pos, pthread_mutex_t *mutex, const pthread_mutexattr_t *mutexattr );
