@@ -579,6 +579,21 @@ ipmsg::getAddressFamilyString( int family )
 	IPMSG_FUNC_RETURN( "other" );
 }
 
+/**
+ * Ʊåȥեߥ꤫Ƚꤹ롣
+ * @param base åȥɥ쥹
+ * @param check åȥɥ쥹
+ * @retval true:Ʊ졣
+ * @retval false:ƱǤʤ
+ */
+bool
+ipmsg::isSameSockAddressFamily( struct sockaddr_storage base, struct sockaddr_storage check )
+{
+	if ( base.ss_family == check.ss_family ) {
+		return true;
+	}
+	return false;
+}
 /**
  * Ʊåȥɥ쥹Ƚꤹ롣
  * @param base åȥɥ쥹
